@@ -209,21 +209,6 @@ def alerts_query(context, query):
         format_table.add_row([alert['message'], alert['tags'], alert['integration']['type'], alert['createdAt']])
     print(format_table)
 
-@bootstrapper.group()
-@click.pass_context
-def version(context):  # pylint: disable=unused-argument
-    """Sub-command for Opsgeniecli. This function is a placeholder to maintain the correct hierarchy for the cli"""
-    pass
-
-
-@version.command(name='show')
-@click.pass_context
-def show_version(context):
-    basepath = os.path.dirname(__file__)
-    filepath = os.path.abspath(os.path.join(basepath, "..", ".VERSION"))
-    with open(filepath, 'r') as file:
-        data = file.read().replace('\n', '')
-    print(f"Opsgeniecli version: {data}")
 
 @alerts.command(name='list')
 @click.option('--active', default=False, is_flag=True)
